<?php
/*
Plugin Name: Remove Category Base
Plugin URI: https://www.linh.pro/wordpress/plugins/
Description: Loại bỏ '/category/' khỏi URL danh mục trong WordPress.
Version: 1.0
Author: Linh Tran
Author URI: https://linh.pro
License: GPL2
*/

// Loại bỏ category khỏi URL danh mục
function remove_category_base() {
    global $wp_rewrite;
    // Đặt permalink của danh mục thành 'prefix/category/'
    $wp_rewrite->extra_permastructs['category']['struct'] = '%category%';
}
add_action('init', 'remove_category_base');

// Loại bỏ '/category/' từ đường dẫn URL danh mục
function remove_category_slug($cat_rewrite) {
    $cat_rewrite = str_replace('/category/', '/', $cat_rewrite);
    return $cat_rewrite;
}
add_filter('category_rewrite_rules', 'remove_category_slug');

// Cập nhật rules của rewrite sau khi loại bỏ '/category/'
function update_category_rewrite_rules($category_rewrite) {
    $category_rewrite = array();
    $categories = get_categories(array('hide_empty' => false));
    foreach($categories as $category) {
        $category_nicename = $category->slug;
        if ($category->parent == $category->cat_ID) {
            $category->parent = 0;
        } elseif($category->parent != 0) {
            $category_nicename = get_category_parents($category->parent, false, '/', true) . $category_nicename;
        }
        $category_rewrite['(' . $category_nicename . ')/(?:feed/)?(feed|rdf|rss|rss2|atom)/?$'] = 'index.php?category_name=$matches[1]&feed=$matches[2]';
        $category_rewrite['(' . $category_nicename . ')/page/?([0-9]{1,})/?$'] = 'index.php?category_name=$matches[1]&paged=$matches[2]';
        $category_rewrite['(' . $category_nicename . ')/?$'] = 'index.php?category_name=$matches[1]';
    }
    return $category_rewrite;
}
add_filter('category_rewrite_rules', 'update_category_rewrite_rules');

// Load lại rules của rewrite sau khi thay đổi
function flush_rewrite_rules_when_category_changes($term_id) {
    global $wp_rewrite;
    $wp_rewrite->flush_rules();
}
add_action('edited_category', 'flush_rewrite_rules_when_category_changes');
add_action('delete_category', 'flush_rewrite_rules_when_category_changes');
add_action('create_category', 'flush_rewrite_rules_when_category_changes');
